from dataclasses import dataclass, field
from typing import Optional

from casereports import Publisher

from .constructors import CitationType, parse_citations


@dataclass
class Citation:
    model: CitationType
    docket: Optional[str] = None
    scra: Optional[str] = None
    phil: Optional[str] = None
    offg: Optional[str] = None

    def __post_init__(self):

        try:
            if self.model.ids:  # if Report model only, no ids will exist
                self.docket = self.model.__str__()
        except:
            ...

        if self.model.publisher == Publisher.Phil.label:
            self.phil = self.model.volpubpage
        elif self.model.publisher == Publisher.Scra.label:
            self.scra = self.model.volpubpage
        elif self.model.publisher == Publisher.Offg.label:
            self.offg = self.model.volpubpage


@dataclass
class CitationDocument:
    text: str
    citations: list[Citation] = field(default_factory=list)

    def __post_init__(self):
        self.citations = [Citation(c) for c in parse_citations(self.text)]
